# Wisconsin

## Contact Info
### Media Contact (preferred)
dwdsocommunicationsoffice@dwd.wisconsin.gov
(608) 266-2722

### Other Contact
Bureau of Workforce Training, Program Administration Section
WIOATitleI@dwd.wisconsin.gov
201 East Washington Avenue
Madison, WI 53707
(608) 405-4070

### July 23, 2021
Sent an email asking about the 'Y' column. Hopefully we get a response! Seems like it's valid data, just unmarked.

RESPONSE:
Hi Cody –
The unlabeled column you cite in your inquiry denotes whether an update to the notice was received at some point in time after receiving the initial notice.
Thanks!
Tyler

So it's a column we can drop in our analysis.

### July 20, 2021
Unexpected "Y" values were showing up in some rows, as if part of a column that had no column header, throwing a wrench in the data standardization program.

Let's ask WI if this actually means anything so we can slap the right field on it during processing. See data_interview.md in the bln-onboarding repo for help.
![image](https://user-images.githubusercontent.com/20691507/126409338-d15fa093-3a2b-48de-9c1f-7b1dea380bc0.png)
